diff --git a/.project b/.project
deleted file mode 100644
index 88dedfc..0000000
--- a/.project
+++ /dev/null
@@ -1,33 +0,0 @@
-
-
- Android2Poche
-
-
-
-
-
- com.android.ide.eclipse.adt.ResourceManagerBuilder
-
-
-
-
- com.android.ide.eclipse.adt.PreCompilerBuilder
-
-
-
-
- org.eclipse.jdt.core.javabuilder
-
-
-
-
- com.android.ide.eclipse.adt.ApkBuilder
-
-
-
-
-
- com.android.ide.eclipse.adt.AndroidNature
- org.eclipse.jdt.core.javanature
-
-
diff --git a/AndroidManifest.xml b/AndroidManifest.xml
index 5efc404..c39d99e 100644
--- a/AndroidManifest.xml
+++ b/AndroidManifest.xml
@@ -1,6 +1,6 @@
+ android:label="@string/app_name" android:theme="@android:style/Theme.NoTitleBar">
diff --git a/res/drawable-hdpi/icon.png b/res/drawable-hdpi/icon.png
index cb69d29..e167d3a 100644
Binary files a/res/drawable-hdpi/icon.png and b/res/drawable-hdpi/icon.png differ
diff --git a/res/drawable-ldpi/icon.png b/res/drawable-ldpi/icon.png
index 2a614cb..205053e 100644
Binary files a/res/drawable-ldpi/icon.png and b/res/drawable-ldpi/icon.png differ
diff --git a/res/drawable-mdpi/icon.png b/res/drawable-mdpi/icon.png
index 230d39a..cb03ec3 100644
Binary files a/res/drawable-mdpi/icon.png and b/res/drawable-mdpi/icon.png differ
diff --git a/res/drawable-xhdpi/icon.png b/res/drawable-xhdpi/icon.png
index d4ddd19..f210537 100644
Binary files a/res/drawable-xhdpi/icon.png and b/res/drawable-xhdpi/icon.png differ
diff --git a/res/values/strings.xml b/res/values/strings.xml
index ae764f8..4c9f4c4 100644
--- a/res/values/strings.xml
+++ b/res/values/strings.xml
@@ -1,12 +1,12 @@
- Welcome to Poche !
- Poche
+ In the poche !
+ In the poche
By GAULUPEAU Jonathan
- To save a web page to Poche, open the page in a browser then tap Share and tap on Poche. \nYou could then see your Poche login page. \nAnd it\'s done ! \nMore infos about Poche at http://www.inthepoche.com
- Done
+ To save a web page to poche, open the page in a browser then tap Share and tap on In the poche. \nYou could then see your Poche login page. \nAnd it\'s done ! \nMore infos about poche at http://www.inthepoche.com
+ Save
Which browser would you like to use?
- http://links.gaulupeau.fr
- Your Poche URL :
+ http://cv.gaulupeau.fr
+ Your poche URL :
Examples:\nhttp://poche.example.fr\nhttp://www.example.fr/poche
diff --git a/src/fr/gaulupeau/apps/Poche/Poche.java b/src/fr/gaulupeau/apps/Poche/Poche.java
index 8914ae7..7f84771 100644
--- a/src/fr/gaulupeau/apps/Poche/Poche.java
+++ b/src/fr/gaulupeau/apps/Poche/Poche.java
@@ -8,6 +8,7 @@
package fr.gaulupeau.apps.Poche;
+import fr.gaulupeau.apps.InThePoche.R;
import java.io.UnsupportedEncodingException;
import android.annotation.TargetApi;
@@ -52,7 +53,7 @@ import android.widget.TextView;
// ACTION_SEND is called when sharing, get the title and URL from
// the call
String pageUrl = extras.getString("android.intent.extra.TEXT");
// Start to build the Delicious URL
Uri.Builder pocheSaveUrl = Uri.parse(pocheUrl).buildUpon();
// Add the parameters from the call
pocheSaveUrl.appendQueryParameter("action", "add");
@@ -52,7 +53,7 @@ import android.widget.TextView;
// the call
String pageUrl = extras.getString("android.intent.extra.TEXT");
- // Start to build the Delicious URL
+ // Start to build the poche URL
Uri.Builder pocheSaveUrl = Uri.parse(pocheUrl).buildUpon();
// Add the parameters from the call